package com.yiqi.system.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.system.domain.SysStoreArea;
import org.apache.ibatis.annotations.Mapper;

/**
 * 门店区域Mapper接口
 *
 * @author xiaohei
 * @date 2023-08-09
 */
public interface SysStoreAreaMapper extends BaseMapper<SysStoreArea> {
    /**
     * 查询门店区域
     *
     * @param id 门店区域主键
     * @return 门店区域
     */
    public SysStoreArea selectSysStoreAreaById(Long id);

    /**
     * 查询门店区域列表
     *
     * @param sysStoreArea 门店区域
     * @return 门店区域集合
     */
    public List<SysStoreArea> selectSysStoreAreaList(SysStoreArea sysStoreArea);

    /**
     * 新增门店区域
     *
     * @param sysStoreArea 门店区域
     * @return 结果
     */
    public int insertSysStoreArea(SysStoreArea sysStoreArea);

    /**
     * 修改门店区域
     *
     * @param sysStoreArea 门店区域
     * @return 结果
     */
    public int updateSysStoreArea(SysStoreArea sysStoreArea);

    /**
     * 删除门店区域
     *
     * @param id 门店区域主键
     * @return 结果
     */
    public int deleteSysStoreAreaById(Long id);

    /**
     * 批量删除门店区域
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysStoreAreaByIds(Long[] ids);
}
