package com.yiqi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.system.domain.SysStoreArea;
import com.yiqi.system.service.ISysStoreAreaService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 门店区域Controller
 *
 * @author ruoyi
 * @date 2023-08-10
 */
@Api(tags = "管理后台 - 门店区域")
@RestController
@RequestMapping(UrlConstants.managerApi + "/system/storeArea")
public class SysStoreAreaController extends BaseController {
    @Autowired
    private ISysStoreAreaService sysStoreAreaService;

    /**
     * 查询门店区域列表
     */
    @PreAuthorize("@ss.hasPermi('system:storeArea:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询门店区域列表")
    public TableDataInfo list(SysStoreArea sysStoreArea) {
        startPage();
        List<SysStoreArea> list = sysStoreAreaService.selectSysStoreAreaList(sysStoreArea);
        return getDataTable(list);
    }

    /**
     * 导出门店区域列表
     */
    @PreAuthorize("@ss.hasPermi('system:storeArea:export')")
    @Log(title = "门店区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出门店区域列表")
    public void export(HttpServletResponse response, SysStoreArea sysStoreArea) {
        List<SysStoreArea> list = sysStoreAreaService.selectSysStoreAreaList(sysStoreArea);
        ExcelUtil<SysStoreArea> util = new ExcelUtil<SysStoreArea>(SysStoreArea. class);
        util.exportExcel(response, list, "门店区域数据");
    }

    /**
     * 获取门店区域详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:storeArea:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取门店区域详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysStoreAreaService.selectSysStoreAreaById(id));
    }

    /**
     * 新增门店区域
     */
    @PreAuthorize("@ss.hasPermi('system:storeArea:add')")
    @Log(title = "门店区域", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增门店区域")
    public AjaxResult add(@RequestBody SysStoreArea sysStoreArea) {
        sysStoreArea.setCreateById(getUserId());
        sysStoreArea.setCreateBy(getUsername());
        return toAjax(sysStoreAreaService.insertSysStoreArea(sysStoreArea));
    }

    /**
     * 修改门店区域
     */
    @PreAuthorize("@ss.hasPermi('system:storeArea:edit')")
    @Log(title = "门店区域", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改门店区域")
    public AjaxResult edit(@RequestBody SysStoreArea sysStoreArea) {
        sysStoreArea.setUpdateById(getUserId());
        sysStoreArea.setUpdateBy(getUsername());
        return toAjax(sysStoreAreaService.updateSysStoreArea(sysStoreArea));
    }

    /**
     * 删除门店区域
     */
    @PreAuthorize("@ss.hasPermi('system:storeArea:remove')")
    @Log(title = "门店区域", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除门店区域")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysStoreAreaService.deleteSysStoreAreaByIds(ids));
    }
}
